# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/naming/v1/name_verification.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/naming/v1/name_verification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,agntcy/dir/naming/v1/name_verification.proto\x12\x14\x61gntcy.dir.naming.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\x0cVerification\x12\x42\n\x06\x64omain\x18\x01 \x01(\x0b\x32(.agntcy.dir.naming.v1.DomainVerificationH\x00R\x06\x64omainB\x06\n\x04info\"\x98\x01\n\x12\x44omainVerification\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x16\n\x06method\x18\x02 \x01(\tR\x06method\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\x12;\n\x0bverified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAtB\xc9\x01\n\x18\x63om.agntcy.dir.naming.v1B\x15NameVerificationProtoP\x01Z#github.com/agntcy/dir/api/naming/v1\xa2\x02\x03\x41\x44N\xaa\x02\x14\x41gntcy.Dir.Naming.V1\xca\x02\x14\x41gntcy\\Dir\\Naming\\V1\xe2\x02 Agntcy\\Dir\\Naming\\V1\\GPBMetadata\xea\x02\x17\x41gntcy::Dir::Naming::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.naming.v1.name_verification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.agntcy.dir.naming.v1B\025NameVerificationProtoP\001Z#github.com/agntcy/dir/api/naming/v1\242\002\003ADN\252\002\024Agntcy.Dir.Naming.V1\312\002\024Agntcy\\Dir\\Naming\\V1\342\002 Agntcy\\Dir\\Naming\\V1\\GPBMetadata\352\002\027Agntcy::Dir::Naming::V1'
  _globals['_VERIFICATION']._serialized_start=103
  _globals['_VERIFICATION']._serialized_end=193
  _globals['_DOMAINVERIFICATION']._serialized_start=196
  _globals['_DOMAINVERIFICATION']._serialized_end=348
# @@protoc_insertion_point(module_scope)
