# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/sign/v1/sign_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/sign/v1/sign_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agntcy.dir.core.v1 import record_pb2 as agntcy_dot_dir_dot_core_dot_v1_dot_record__pb2
from agntcy.dir.sign.v1 import signature_pb2 as agntcy_dot_dir_dot_sign_dot_v1_dot_signature__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%agntcy/dir/sign/v1/sign_service.proto\x12\x12\x61gntcy.dir.sign.v1\x1a\x1f\x61gntcy/dir/core/v1/record.proto\x1a\"agntcy/dir/sign/v1/signature.proto\"\x8f\x02\n\x0fSignOptionsOIDC\x12\x1d\n\nfulcio_url\x18\x01 \x01(\tR\tfulcioUrl\x12\x1b\n\trekor_url\x18\x02 \x01(\tR\x08rekorUrl\x12#\n\rtimestamp_url\x18\x03 \x01(\tR\x0ctimestampUrl\x12*\n\x11oidc_provider_url\x18\x04 \x01(\tR\x0foidcProviderUrl\x12$\n\x0eoidc_client_id\x18\x05 \x01(\tR\x0coidcClientId\x12,\n\x12oidc_client_secret\x18\x06 \x01(\tR\x10oidcClientSecret\x12\x1b\n\tskip_tlog\x18\x07 \x01(\x08R\x08skipTlog\"\xc4\x01\n\x11VerifyOptionsOIDC\x12$\n\x0etuf_mirror_url\x18\x01 \x01(\tR\x0ctufMirrorUrl\x12*\n\x11trusted_root_path\x18\x02 \x01(\tR\x0ftrustedRootPath\x12\x1f\n\x0bignore_tlog\x18\x03 \x01(\x08R\nignoreTlog\x12\x1d\n\nignore_tsa\x18\x04 \x01(\x08R\tignoreTsa\x12\x1d\n\nignore_sct\x18\x05 \x01(\x08R\tignoreSct\"\x90\x01\n\x0bSignRequest\x12<\n\nrecord_ref\x18\x01 \x01(\x0b\x32\x1d.agntcy.dir.core.v1.RecordRefR\trecordRef\x12\x43\n\x08provider\x18\x02 \x01(\x0b\x32\'.agntcy.dir.sign.v1.SignRequestProviderR\x08provider\"\x8d\x01\n\x13SignRequestProvider\x12\x33\n\x03key\x18\x01 \x01(\x0b\x32\x1f.agntcy.dir.sign.v1.SignWithKeyH\x00R\x03key\x12\x36\n\x04oidc\x18\x02 \x01(\x0b\x32 .agntcy.dir.sign.v1.SignWithOIDCH\x00R\x04oidcB\t\n\x07request\"\\\n\x0bSignWithKey\x12\x1f\n\x0bprivate_key\x18\x01 \x01(\tR\nprivateKey\x12\x1f\n\x08password\x18\x02 \x01(\x0cH\x00R\x08password\x88\x01\x01\x42\x0b\n\t_password\"y\n\x0cSignWithOIDC\x12\x19\n\x08id_token\x18\x01 \x01(\tR\x07idToken\x12\x42\n\x07options\x18\x02 \x01(\x0b\x32#.agntcy.dir.sign.v1.SignOptionsOIDCH\x00R\x07options\x88\x01\x01\x42\n\n\x08_options\"K\n\x0cSignResponse\x12;\n\tsignature\x18\x01 \x01(\x0b\x32\x1d.agntcy.dir.sign.v1.SignatureR\tsignature\"\xb5\x01\n\rVerifyRequest\x12<\n\nrecord_ref\x18\x01 \x01(\x0b\x32\x1d.agntcy.dir.core.v1.RecordRefR\trecordRef\x12\x45\n\x08provider\x18\x02 \x01(\x0b\x32).agntcy.dir.sign.v1.VerifyRequestProviderR\x08provider\x12\x1f\n\x0b\x66rom_server\x18\x03 \x01(\x08R\nfromServer\"\xca\x01\n\x15VerifyRequestProvider\x12\x35\n\x03key\x18\x01 \x01(\x0b\x32!.agntcy.dir.sign.v1.VerifyWithKeyH\x00R\x03key\x12\x38\n\x04oidc\x18\x02 \x01(\x0b\x32\".agntcy.dir.sign.v1.VerifyWithOIDCH\x00R\x04oidc\x12\x35\n\x03\x61ny\x18\x03 \x01(\x0b\x32!.agntcy.dir.sign.v1.VerifyWithAnyH\x00R\x03\x61nyB\t\n\x07request\".\n\rVerifyWithKey\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\"\x94\x01\n\x0eVerifyWithOIDC\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x18\n\x07subject\x18\x02 \x01(\tR\x07subject\x12\x44\n\x07options\x18\x03 \x01(\x0b\x32%.agntcy.dir.sign.v1.VerifyOptionsOIDCH\x00R\x07options\x88\x01\x01\x42\n\n\x08_options\"o\n\rVerifyWithAny\x12M\n\x0coidc_options\x18\x01 \x01(\x0b\x32%.agntcy.dir.sign.v1.VerifyOptionsOIDCH\x00R\x0boidcOptions\x88\x01\x01\x42\x0f\n\r_oidc_options\"\xa0\x01\n\x0eVerifyResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x38\n\x07signers\x18\x02 \x03(\x0b\x32\x1e.agntcy.dir.sign.v1.SignerInfoR\x07signers\x12(\n\rerror_message\x18\x03 \x01(\tH\x00R\x0c\x65rrorMessage\x88\x01\x01\x42\x10\n\x0e_error_message\"\x85\x01\n\nSignerInfo\x12\x35\n\x03key\x18\x01 \x01(\x0b\x32!.agntcy.dir.sign.v1.SignerInfoKeyH\x00R\x03key\x12\x38\n\x04oidc\x18\x02 \x01(\x0b\x32\".agntcy.dir.sign.v1.SignerInfoOIDCH\x00R\x04oidcB\x06\n\x04type\"L\n\rSignerInfoKey\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\x12\x1c\n\talgorithm\x18\x02 \x01(\tR\talgorithm\"q\n\x0eSignerInfoOIDC\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x18\n\x07subject\x18\x02 \x01(\tR\x07subject\x12-\n\x12\x63\x65rtificate_issuer\x18\x03 \x01(\tR\x11\x63\x65rtificateIssuer2\xa9\x01\n\x0bSignService\x12I\n\x04Sign\x12\x1f.agntcy.dir.sign.v1.SignRequest\x1a .agntcy.dir.sign.v1.SignResponse\x12O\n\x06Verify\x12!.agntcy.dir.sign.v1.VerifyRequest\x1a\".agntcy.dir.sign.v1.VerifyResponseB\xb8\x01\n\x16\x63om.agntcy.dir.sign.v1B\x10SignServiceProtoP\x01Z!github.com/agntcy/dir/api/sign/v1\xa2\x02\x03\x41\x44S\xaa\x02\x12\x41gntcy.Dir.Sign.V1\xca\x02\x12\x41gntcy\\Dir\\Sign\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Sign\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Sign::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.sign.v1.sign_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.sign.v1B\020SignServiceProtoP\001Z!github.com/agntcy/dir/api/sign/v1\242\002\003ADS\252\002\022Agntcy.Dir.Sign.V1\312\002\022Agntcy\\Dir\\Sign\\V1\342\002\036Agntcy\\Dir\\Sign\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Sign::V1'
  _globals['_SIGNOPTIONSOIDC']._serialized_start=131
  _globals['_SIGNOPTIONSOIDC']._serialized_end=402
  _globals['_VERIFYOPTIONSOIDC']._serialized_start=405
  _globals['_VERIFYOPTIONSOIDC']._serialized_end=601
  _globals['_SIGNREQUEST']._serialized_start=604
  _globals['_SIGNREQUEST']._serialized_end=748
  _globals['_SIGNREQUESTPROVIDER']._serialized_start=751
  _globals['_SIGNREQUESTPROVIDER']._serialized_end=892
  _globals['_SIGNWITHKEY']._serialized_start=894
  _globals['_SIGNWITHKEY']._serialized_end=986
  _globals['_SIGNWITHOIDC']._serialized_start=988
  _globals['_SIGNWITHOIDC']._serialized_end=1109
  _globals['_SIGNRESPONSE']._serialized_start=1111
  _globals['_SIGNRESPONSE']._serialized_end=1186
  _globals['_VERIFYREQUEST']._serialized_start=1189
  _globals['_VERIFYREQUEST']._serialized_end=1370
  _globals['_VERIFYREQUESTPROVIDER']._serialized_start=1373
  _globals['_VERIFYREQUESTPROVIDER']._serialized_end=1575
  _globals['_VERIFYWITHKEY']._serialized_start=1577
  _globals['_VERIFYWITHKEY']._serialized_end=1623
  _globals['_VERIFYWITHOIDC']._serialized_start=1626
  _globals['_VERIFYWITHOIDC']._serialized_end=1774
  _globals['_VERIFYWITHANY']._serialized_start=1776
  _globals['_VERIFYWITHANY']._serialized_end=1887
  _globals['_VERIFYRESPONSE']._serialized_start=1890
  _globals['_VERIFYRESPONSE']._serialized_end=2050
  _globals['_SIGNERINFO']._serialized_start=2053
  _globals['_SIGNERINFO']._serialized_end=2186
  _globals['_SIGNERINFOKEY']._serialized_start=2188
  _globals['_SIGNERINFOKEY']._serialized_end=2264
  _globals['_SIGNERINFOOIDC']._serialized_start=2266
  _globals['_SIGNERINFOOIDC']._serialized_end=2379
  _globals['_SIGNSERVICE']._serialized_start=2382
  _globals['_SIGNSERVICE']._serialized_end=2551
# @@protoc_insertion_point(module_scope)
