# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/routing/v1/publication_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/routing/v1/publication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agntcy.dir.routing.v1 import routing_service_pb2 as agntcy_dot_dir_dot_routing_dot_v1_dot_routing__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/agntcy/dir/routing/v1/publication_service.proto\x12\x15\x61gntcy.dir.routing.v1\x1a+agntcy/dir/routing/v1/routing_service.proto\"B\n\x19\x43reatePublicationResponse\x12%\n\x0epublication_id\x18\x01 \x01(\tR\rpublicationId\"f\n\x17ListPublicationsRequest\x12\x19\n\x05limit\x18\x02 \x01(\rH\x00R\x05limit\x88\x01\x01\x12\x1b\n\x06offset\x18\x03 \x01(\rH\x01R\x06offset\x88\x01\x01\x42\x08\n\x06_limitB\t\n\x07_offset\"\xcc\x01\n\x14ListPublicationsItem\x12%\n\x0epublication_id\x18\x01 \x01(\tR\rpublicationId\x12@\n\x06status\x18\x02 \x01(\x0e\x32(.agntcy.dir.routing.v1.PublicationStatusR\x06status\x12!\n\x0c\x63reated_time\x18\x03 \x01(\tR\x0b\x63reatedTime\x12(\n\x10last_update_time\x18\x04 \x01(\tR\x0elastUpdateTime\">\n\x15GetPublicationRequest\x12%\n\x0epublication_id\x18\x01 \x01(\tR\rpublicationId\"\xce\x01\n\x16GetPublicationResponse\x12%\n\x0epublication_id\x18\x01 \x01(\tR\rpublicationId\x12@\n\x06status\x18\x02 \x01(\x0e\x32(.agntcy.dir.routing.v1.PublicationStatusR\x06status\x12!\n\x0c\x63reated_time\x18\x03 \x01(\tR\x0b\x63reatedTime\x12(\n\x10last_update_time\x18\x04 \x01(\tR\x0elastUpdateTime*\xbc\x01\n\x11PublicationStatus\x12\"\n\x1ePUBLICATION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1aPUBLICATION_STATUS_PENDING\x10\x01\x12\"\n\x1ePUBLICATION_STATUS_IN_PROGRESS\x10\x02\x12 \n\x1cPUBLICATION_STATUS_COMPLETED\x10\x03\x12\x1d\n\x19PUBLICATION_STATUS_FAILED\x10\x04\x32\xe4\x02\n\x12PublicationService\x12l\n\x11\x43reatePublication\x12%.agntcy.dir.routing.v1.PublishRequest\x1a\x30.agntcy.dir.routing.v1.CreatePublicationResponse\x12q\n\x10ListPublications\x12..agntcy.dir.routing.v1.ListPublicationsRequest\x1a+.agntcy.dir.routing.v1.ListPublicationsItem0\x01\x12m\n\x0eGetPublication\x12,.agntcy.dir.routing.v1.GetPublicationRequest\x1a-.agntcy.dir.routing.v1.GetPublicationResponseB\xd1\x01\n\x19\x63om.agntcy.dir.routing.v1B\x17PublicationServiceProtoP\x01Z$github.com/agntcy/dir/api/routing/v1\xa2\x02\x03\x41\x44R\xaa\x02\x15\x41gntcy.Dir.Routing.V1\xca\x02\x15\x41gntcy\\Dir\\Routing\\V1\xe2\x02!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\xea\x02\x18\x41gntcy::Dir::Routing::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.routing.v1.publication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.agntcy.dir.routing.v1B\027PublicationServiceProtoP\001Z$github.com/agntcy/dir/api/routing/v1\242\002\003ADR\252\002\025Agntcy.Dir.Routing.V1\312\002\025Agntcy\\Dir\\Routing\\V1\342\002!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\352\002\030Agntcy::Dir::Routing::V1'
  _globals['_PUBLICATIONSTATUS']._serialized_start=772
  _globals['_PUBLICATIONSTATUS']._serialized_end=960
  _globals['_CREATEPUBLICATIONRESPONSE']._serialized_start=119
  _globals['_CREATEPUBLICATIONRESPONSE']._serialized_end=185
  _globals['_LISTPUBLICATIONSREQUEST']._serialized_start=187
  _globals['_LISTPUBLICATIONSREQUEST']._serialized_end=289
  _globals['_LISTPUBLICATIONSITEM']._serialized_start=292
  _globals['_LISTPUBLICATIONSITEM']._serialized_end=496
  _globals['_GETPUBLICATIONREQUEST']._serialized_start=498
  _globals['_GETPUBLICATIONREQUEST']._serialized_end=560
  _globals['_GETPUBLICATIONRESPONSE']._serialized_start=563
  _globals['_GETPUBLICATIONRESPONSE']._serialized_end=769
  _globals['_PUBLICATIONSERVICE']._serialized_start=963
  _globals['_PUBLICATIONSERVICE']._serialized_end=1319
# @@protoc_insertion_point(module_scope)
