# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/routing/v1/record_query.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/routing/v1/record_query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(agntcy/dir/routing/v1/record_query.proto\x12\x15\x61gntcy.dir.routing.v1\"_\n\x0bRecordQuery\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.agntcy.dir.routing.v1.RecordQueryTypeR\x04type\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value*\xac\x01\n\x0fRecordQueryType\x12!\n\x1dRECORD_QUERY_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17RECORD_QUERY_TYPE_SKILL\x10\x01\x12\x1d\n\x19RECORD_QUERY_TYPE_LOCATOR\x10\x02\x12\x1c\n\x18RECORD_QUERY_TYPE_DOMAIN\x10\x03\x12\x1c\n\x18RECORD_QUERY_TYPE_MODULE\x10\x04\x42\xca\x01\n\x19\x63om.agntcy.dir.routing.v1B\x10RecordQueryProtoP\x01Z$github.com/agntcy/dir/api/routing/v1\xa2\x02\x03\x41\x44R\xaa\x02\x15\x41gntcy.Dir.Routing.V1\xca\x02\x15\x41gntcy\\Dir\\Routing\\V1\xe2\x02!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\xea\x02\x18\x41gntcy::Dir::Routing::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.routing.v1.record_query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.agntcy.dir.routing.v1B\020RecordQueryProtoP\001Z$github.com/agntcy/dir/api/routing/v1\242\002\003ADR\252\002\025Agntcy.Dir.Routing.V1\312\002\025Agntcy\\Dir\\Routing\\V1\342\002!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\352\002\030Agntcy::Dir::Routing::V1'
  _globals['_RECORDQUERYTYPE']._serialized_start=165
  _globals['_RECORDQUERYTYPE']._serialized_end=337
  _globals['_RECORDQUERY']._serialized_start=67
  _globals['_RECORDQUERY']._serialized_end=162
# @@protoc_insertion_point(module_scope)
