# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/routing/v1/peer.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/routing/v1/peer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n agntcy/dir/routing/v1/peer.proto\x12\x15\x61gntcy.dir.routing.v1\"\x87\x02\n\x04Peer\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x61\x64\x64rs\x18\x02 \x03(\tR\x05\x61\x64\x64rs\x12N\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32,.agntcy.dir.routing.v1.Peer.AnnotationsEntryR\x0b\x61nnotations\x12I\n\nconnection\x18\x04 \x01(\x0e\x32).agntcy.dir.routing.v1.PeerConnectionTypeR\nconnection\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xaf\x01\n\x12PeerConnectionType\x12&\n\"PEER_CONNECTION_TYPE_NOT_CONNECTED\x10\x00\x12\"\n\x1ePEER_CONNECTION_TYPE_CONNECTED\x10\x01\x12$\n PEER_CONNECTION_TYPE_CAN_CONNECT\x10\x02\x12\'\n#PEER_CONNECTION_TYPE_CANNOT_CONNECT\x10\x03\x42\xc3\x01\n\x19\x63om.agntcy.dir.routing.v1B\tPeerProtoP\x01Z$github.com/agntcy/dir/api/routing/v1\xa2\x02\x03\x41\x44R\xaa\x02\x15\x41gntcy.Dir.Routing.V1\xca\x02\x15\x41gntcy\\Dir\\Routing\\V1\xe2\x02!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\xea\x02\x18\x41gntcy::Dir::Routing::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.routing.v1.peer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.agntcy.dir.routing.v1B\tPeerProtoP\001Z$github.com/agntcy/dir/api/routing/v1\242\002\003ADR\252\002\025Agntcy.Dir.Routing.V1\312\002\025Agntcy\\Dir\\Routing\\V1\342\002!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\352\002\030Agntcy::Dir::Routing::V1'
  _globals['_PEER_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_PEER_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_PEERCONNECTIONTYPE']._serialized_start=326
  _globals['_PEERCONNECTIONTYPE']._serialized_end=501
  _globals['_PEER']._serialized_start=60
  _globals['_PEER']._serialized_end=323
  _globals['_PEER_ANNOTATIONSENTRY']._serialized_start=261
  _globals['_PEER_ANNOTATIONSENTRY']._serialized_end=323
# @@protoc_insertion_point(module_scope)
