# Copyright AGNTCY Contributors (https://github.com/agntcy)
# SPDX-License-Identifier: Apache-2.0

from agntcy.dir.events.v1.event_service_pb2 import *
from agntcy.dir.events.v1.event_service_pb2_grpc import *
