# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/sign/v1/signature.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/sign/v1/signature.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"agntcy/dir/sign/v1/signature.proto\x12\x12\x61gntcy.dir.sign.v1\"\xe2\x02\n\tSignature\x12P\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32..agntcy.dir.sign.v1.Signature.AnnotationsEntryR\x0b\x61nnotations\x12\x1b\n\tsigned_at\x18\x02 \x01(\tR\x08signedAt\x12\x1c\n\talgorithm\x18\x03 \x01(\tR\talgorithm\x12\x1c\n\tsignature\x18\x04 \x01(\tR\tsignature\x12 \n\x0b\x63\x65rtificate\x18\x05 \x01(\tR\x0b\x63\x65rtificate\x12!\n\x0c\x63ontent_type\x18\x06 \x01(\tR\x0b\x63ontentType\x12%\n\x0e\x63ontent_bundle\x18\x07 \x01(\tR\rcontentBundle\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xb6\x01\n\x16\x63om.agntcy.dir.sign.v1B\x0eSignatureProtoP\x01Z!github.com/agntcy/dir/api/sign/v1\xa2\x02\x03\x41\x44S\xaa\x02\x12\x41gntcy.Dir.Sign.V1\xca\x02\x12\x41gntcy\\Dir\\Sign\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Sign\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Sign::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.sign.v1.signature_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.sign.v1B\016SignatureProtoP\001Z!github.com/agntcy/dir/api/sign/v1\242\002\003ADS\252\002\022Agntcy.Dir.Sign.V1\312\002\022Agntcy\\Dir\\Sign\\V1\342\002\036Agntcy\\Dir\\Sign\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Sign::V1'
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_SIGNATURE']._serialized_start=59
  _globals['_SIGNATURE']._serialized_end=413
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._serialized_start=351
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._serialized_end=413
# @@protoc_insertion_point(module_scope)
