# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/core/v1/referrer.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/core/v1/referrer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!agntcy/dir/core/v1/referrer.proto\x12\x12\x61gntcy.dir.core.v1\"\x1f\n\x0bReferrerRef\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63idB\xb5\x01\n\x16\x63om.agntcy.dir.core.v1B\rReferrerProtoP\x01Z!github.com/agntcy/dir/api/core/v1\xa2\x02\x03\x41\x44\x43\xaa\x02\x12\x41gntcy.Dir.Core.V1\xca\x02\x12\x41gntcy\\Dir\\Core\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Core\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.core.v1.referrer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.core.v1B\rReferrerProtoP\001Z!github.com/agntcy/dir/api/core/v1\242\002\003ADC\252\002\022Agntcy.Dir.Core.V1\312\002\022Agntcy\\Dir\\Core\\V1\342\002\036Agntcy\\Dir\\Core\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Core::V1'
  _globals['_REFERRERREF']._serialized_start=57
  _globals['_REFERRERREF']._serialized_end=88
# @@protoc_insertion_point(module_scope)
