# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/store/v1/sync_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/store/v1/sync_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&agntcy/dir/store/v1/sync_service.proto\x12\x13\x61gntcy.dir.store.v1\"Y\n\x11\x43reateSyncRequest\x12\x30\n\x14remote_directory_url\x18\x01 \x01(\tR\x12remoteDirectoryUrl\x12\x12\n\x04\x63ids\x18\x02 \x03(\tR\x04\x63ids\"-\n\x12\x43reateSyncResponse\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"_\n\x10ListSyncsRequest\x12\x19\n\x05limit\x18\x02 \x01(\rH\x00R\x05limit\x88\x01\x01\x12\x1b\n\x06offset\x18\x03 \x01(\rH\x01R\x06offset\x88\x01\x01\x42\x08\n\x06_limitB\t\n\x07_offset\"\x93\x01\n\rListSyncsItem\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\x12\x37\n\x06status\x18\x02 \x01(\x0e\x32\x1f.agntcy.dir.store.v1.SyncStatusR\x06status\x12\x30\n\x14remote_directory_url\x18\x03 \x01(\tR\x12remoteDirectoryUrl\")\n\x0eGetSyncRequest\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"\xe2\x01\n\x0fGetSyncResponse\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\x12\x37\n\x06status\x18\x02 \x01(\x0e\x32\x1f.agntcy.dir.store.v1.SyncStatusR\x06status\x12\x30\n\x14remote_directory_url\x18\x03 \x01(\tR\x12remoteDirectoryUrl\x12!\n\x0c\x63reated_time\x18\x04 \x01(\tR\x0b\x63reatedTime\x12(\n\x10last_update_time\x18\x05 \x01(\tR\x0elastUpdateTime\",\n\x11\x44\x65leteSyncRequest\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"\x14\n\x12\x44\x65leteSyncResponse\"#\n!RequestRegistryCredentialsRequest\"\xae\x02\n\"RequestRegistryCredentialsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\x12)\n\x10registry_address\x18\x03 \x01(\tR\x0fregistryAddress\x12\'\n\x0frepository_name\x18\x06 \x01(\tR\x0erepositoryName\x12J\n\nbasic_auth\x18\x04 \x01(\x0b\x32).agntcy.dir.store.v1.BasicAuthCredentialsH\x00R\tbasicAuth\x12\x1a\n\x08insecure\x18\x07 \x01(\x08R\x08insecureB\r\n\x0b\x63redentials\"N\n\x14\x42\x61sicAuthCredentials\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password*\xcb\x01\n\nSyncStatus\x12\x1b\n\x17SYNC_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13SYNC_STATUS_PENDING\x10\x01\x12\x1b\n\x17SYNC_STATUS_IN_PROGRESS\x10\x02\x12\x16\n\x12SYNC_STATUS_FAILED\x10\x03\x12\x1e\n\x1aSYNC_STATUS_DELETE_PENDING\x10\x04\x12\x17\n\x13SYNC_STATUS_DELETED\x10\x05\x12\x19\n\x15SYNC_STATUS_COMPLETED\x10\x06\x32\x8b\x04\n\x0bSyncService\x12]\n\nCreateSync\x12&.agntcy.dir.store.v1.CreateSyncRequest\x1a\'.agntcy.dir.store.v1.CreateSyncResponse\x12X\n\tListSyncs\x12%.agntcy.dir.store.v1.ListSyncsRequest\x1a\".agntcy.dir.store.v1.ListSyncsItem0\x01\x12T\n\x07GetSync\x12#.agntcy.dir.store.v1.GetSyncRequest\x1a$.agntcy.dir.store.v1.GetSyncResponse\x12]\n\nDeleteSync\x12&.agntcy.dir.store.v1.DeleteSyncRequest\x1a\'.agntcy.dir.store.v1.DeleteSyncResponse\x12\x8d\x01\n\x1aRequestRegistryCredentials\x12\x36.agntcy.dir.store.v1.RequestRegistryCredentialsRequest\x1a\x37.agntcy.dir.store.v1.RequestRegistryCredentialsResponseB\xbe\x01\n\x17\x63om.agntcy.dir.store.v1B\x10SyncServiceProtoP\x01Z\"github.com/agntcy/dir/api/store/v1\xa2\x02\x03\x41\x44S\xaa\x02\x13\x41gntcy.Dir.Store.V1\xca\x02\x13\x41gntcy\\Dir\\Store\\V1\xe2\x02\x1f\x41gntcy\\Dir\\Store\\V1\\GPBMetadata\xea\x02\x16\x41gntcy::Dir::Store::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.store.v1.sync_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.agntcy.dir.store.v1B\020SyncServiceProtoP\001Z\"github.com/agntcy/dir/api/store/v1\242\002\003ADS\252\002\023Agntcy.Dir.Store.V1\312\002\023Agntcy\\Dir\\Store\\V1\342\002\037Agntcy\\Dir\\Store\\V1\\GPBMetadata\352\002\026Agntcy::Dir::Store::V1'
  _globals['_SYNCSTATUS']._serialized_start=1211
  _globals['_SYNCSTATUS']._serialized_end=1414
  _globals['_CREATESYNCREQUEST']._serialized_start=63
  _globals['_CREATESYNCREQUEST']._serialized_end=152
  _globals['_CREATESYNCRESPONSE']._serialized_start=154
  _globals['_CREATESYNCRESPONSE']._serialized_end=199
  _globals['_LISTSYNCSREQUEST']._serialized_start=201
  _globals['_LISTSYNCSREQUEST']._serialized_end=296
  _globals['_LISTSYNCSITEM']._serialized_start=299
  _globals['_LISTSYNCSITEM']._serialized_end=446
  _globals['_GETSYNCREQUEST']._serialized_start=448
  _globals['_GETSYNCREQUEST']._serialized_end=489
  _globals['_GETSYNCRESPONSE']._serialized_start=492
  _globals['_GETSYNCRESPONSE']._serialized_end=718
  _globals['_DELETESYNCREQUEST']._serialized_start=720
  _globals['_DELETESYNCREQUEST']._serialized_end=764
  _globals['_DELETESYNCRESPONSE']._serialized_start=766
  _globals['_DELETESYNCRESPONSE']._serialized_end=786
  _globals['_REQUESTREGISTRYCREDENTIALSREQUEST']._serialized_start=788
  _globals['_REQUESTREGISTRYCREDENTIALSREQUEST']._serialized_end=823
  _globals['_REQUESTREGISTRYCREDENTIALSRESPONSE']._serialized_start=826
  _globals['_REQUESTREGISTRYCREDENTIALSRESPONSE']._serialized_end=1128
  _globals['_BASICAUTHCREDENTIALS']._serialized_start=1130
  _globals['_BASICAUTHCREDENTIALS']._serialized_end=1208
  _globals['_SYNCSERVICE']._serialized_start=1417
  _globals['_SYNCSERVICE']._serialized_end=1940
# @@protoc_insertion_point(module_scope)
